%global srcname mirrors-countme
%global pkgname mirrors_countme

%bcond_without auto_buildrequires
%bcond_without poetry_compatible

%bcond_without tests

Name:    python-%{srcname}
Version: 0.1.2
Release:    4%{?dist}
Summary: Parse access_log and count hosts accessing DNF mirrors
URL:     https://github.com/fedora-infra/mirrors-countme
License: GPLv3+
Source0: https://github.com/fedora-infra/mirrors-countme/releases/download/%{version}/%{pkgname}-%{version}.tar.gz
BuildArch: noarch
Requires: sqlite >= 3.0.0

%global _description %{expand:
A python module and scripts for parsing httpd access_log to find requests
including `countme=N`, parse the data included with those requests, and
compile weekly counts of DNF clients broken out by OS name, OS version,
system arch, etc.}

%description %_description


%package -n python%{python3_pkgversion}-%{srcname}
Summary: %{summary}
BuildRequires: python%{python3_pkgversion}-devel
%if ! %{with auto_buildrequires}
BuildRequires: python%{python3_pkgversion}-setuptools
%endif
%if %{with tests}
BuildRequires: glibc-langpack-en
BuildRequires: python%{python3_pkgversion}-hypothesis
BuildRequires: python%{python3_pkgversion}-pytest
BuildRequires: python%{python3_pkgversion}-pytest-cov
BuildRequires: python%{python3_pkgversion}-pytest-xdist
%endif

%description -n python%{python3_pkgversion}-%{srcname} %_description

%prep
%autosetup -n %{pkgname}-%{version}

%if %{with auto_buildrequires}
%generate_buildrequires
%pyproject_buildrequires
%endif

%build
%if %{with poetry_compatible}
%pyproject_wheel
%else
%py3_build
%endif

%install
%if %{with poetry_compatible}
%pyproject_install
%pyproject_save_files %{pkgname}
%else
%py3_install

pushd %{buildroot}
find "./%{python3_sitelib}/%{pkgname}"* -type d | while read d; do
    echo "%dir ${d#./}"
done > %{pyproject_files}
find "./%{python3_sitelib}/%{pkgname}"* -type f | while read f; do
    echo "${f#./}"
done >> %{pyproject_files}
popd
%endif

for script in update-rawdb update-totals sqlite2csv; do
    install -m0755 "scripts/countme-${script}.sh" "%{buildroot}%{_bindir}/"
done

%files -n python%{python3_pkgversion}-%{srcname} -f %{pyproject_files}
%license LICENSE.md
%doc README.md
%{_bindir}/countme-delete-totals
%{_bindir}/countme-parse-access-log
%{_bindir}/countme-totals
%{_bindir}/countme-trim-raw
%{_bindir}/countme-update-rawdb.sh
%{_bindir}/countme-update-totals.sh
%{_bindir}/countme-sqlite2csv.sh

%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 0.1.2-4
- Rebuilt for loongarch64

* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 0.1.2-3
- Rebuilt for loongarch64

* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 0.1.2-2
- Rebuilt for loongarch64

* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.1.2-1
- initial build
